@@ -1,13 +1,17 @@
 """
-Copyright (c) 2020 Samuel Lampa <samuel.lampa@rilnet.com>
+Copyright (c) 2021 Samuel Lampa <samuel.lampa@rilnet.com>
 """
 
 import asyncio
 import typing
 
 
+def run(awaitable, **kwargs):
+    asyncio.run(awaitable, **kwargs)
+
+
 class Process:
-    def run(self):
+    async def run(self):
         raise NotImplementedError(
             f"str(type(self)) can not be used directly, but must be subclassed"
         )
@@ -15,18 +19,13 @@ class Process:
 
 class Network(Process):
     _processes = {}
-    _driver_process = None
-
-    def __init__(self):
-        self._loop = asyncio.get_event_loop()
 
     def add_process(self, name: str, process: Process):
         self._processes[name] = process
-        self._loop.create_task(process.run())
-        self._driver_process = process
+        asyncio.create_task(process.run())
 
-    def run(self):
-        self._loop.run_until_complete(self._driver_process.run())
+    async def run(self):
+        [await p.run() for _, p in self._processes.items()]
 
 
 class Port(asyncio.Queue):
